; LED_Line in Assembler
; Testing MBI Chip IN->OUT
; www.banerled.cm
; MrTip GNU Licence
; Flashing LEDs

.device  atmega8
.nolist
.include "m8def.inc"
.list

.cseg
.org 0

;-------------------------------------------------------------------------------------------------------------------------
rjmp 	RESET 		; Reset Handler
rjmp	intINT0	; 0x0001	; External Interrupt Request 0
rjmp	intINT1	; 0x0002	; External Interrupt Request 1
rjmp	intOC2	; 0x0003	; Timer/Counter2 Compare Match
rjmp	intOVF2	; 0x0004	; Timer/Counter2 Overflow
rjmp	intICP1	; 0x0005	; Timer/Counter1 Capture Event
rjmp	intOC1A	; 0x0006	; Timer/Counter1 Compare Match A
rjmp	intOC1B	; 0x0007	; Timer/Counter1 Compare Match B
rjmp	intOVF1	; 0x0008	; Timer/Counter1 Overflowr
rjmp	intOVF0	; 0x0009	; Timer/Counter0 Overflo
rjmp	intSPI	; 0x000a	; Serial Transfer Complete
rjmp	intURXC	; 0x000b	; USART, Rx Complete
rjmp	intUDRE	; 0x000c	; USART Data Register Empty
rjmp	intUTXC	; 0x000d	; USART, Tx Complete
rjmp	intADCC	; 0x000e	; ADC Conversion Complete
rjmp	intERDY	; 0x000f	; EEPROM Ready
rjmp	intACI	; 0x0010	; Analog Comparator
rjmp	intTWI	; 0x0011	; 2-wire Serial Interface
rjmp	intSPMR	; 0x0012	; Store Program Memory Ready
;-------------------------------------------------------------------------------------------------------------------------
intINT0:	; 0x0001	; External Interrupt Request 0
intINT1:	; 0x0002	; External Interrupt Request 1
intOC2:		; 0x0003	; Timer/Counter2 Compare Match
intOVF2:	; 0x0004	; Timer/Counter2 Overflow
intICP1:	; 0x0005	; Timer/Counter1 Capture Event
intOC1A:	; 0x0006	; Timer/Counter1 Compare Match A
intOC1B:	; 0x0007	; Timer/Counter1 Compare Match B
intOVF1:	; 0x0008	; Timer/Counter1 Overflowr
intOVF0:	; 0x0009	; Timer/Counter0 Overflo
intSPI:		; 0x000a	; Serial Transfer Complete
intURXC:	; 0x000b	; USART, Rx Complete
intUDRE:	; 0x000c	; USART Data Register Empty
intUTXC:	; 0x000d	; USART, Tx Complete
intADCC:	; 0x000e	; ADC Conversion Complete
intERDY:	; 0x000f	; EEPROM Ready
intACI:		; 0x0010	; Analog Comparator
intTWI:		; 0x0011	; 2-wire Serial Interface
intSPMR:	; 0x0012	; Store Program Memory Ready
		reti
;-------------------------------------------------------------------------------------------------------------------------
.equ dR			= PC0
.equ dG			= PC1
.equ dB			= PC2
.equ sG			= PC3
.equ sR			= PC4

.equ DatIn       = PB0	 ;out
.equ Dat         = PD5	 ;out
.equ CLK         = PD6	 ;out
.equ LE 	  	 = PD7	 ;out

.equ RamSize = 1024

.equ Re  = 0x0E2
.equ Gr  = 0x0E3
.equ Bl  = 0x0E4

.equ oRe = 0x0E5
.equ oGr = 0x0E6
.equ oBl = 0x0E7

.equ pZH = 0x0E8
.equ pZL = 0x0E9

.equ fx  = 0x0F0

.equ xr20  = 0x0F1
.equ xr21  = 0x0F2

.equ MBI_Count   = 12	 ; 4x64pix
.equ MBI_RAM     = 0x100  ; 768 bajt = 0x400
;memory
;-------------------------------------------------------------------------------------------------------------------------
.def  colR = r23
.def  colG = r24
.def  colB = r25
.def  cntC = r26

.def  flash	= r14
.def  timer	= r15
;-------------------------------------------------------------------------------------------------------------------------
.MACRO CLK_1
		sbi 	PORTD,CLK  
.ENDMACRO
;-------------------------------------------------------------------------------------------------------------------------
.MACRO CLK_0
		cbi 	PORTD,CLK   
.ENDMACRO
;-------------------------------------------------------------------------------------------------------------------------
.MACRO Dat_0
		cbi		PORTD,Dat
.ENDMACRO
;-------------------------------------------------------------------------------------------------------------------------
.MACRO Dat_1
		sbi 	PORTD,Dat      
.ENDMACRO
;-------------------------------------------------------------------------------------------------------------------------
.MACRO LE_0
		cbi 	PORTD,LE
.ENDMACRO
;-------------------------------------------------------------------------------------------------------------------------
.MACRO LE_1
		sbi 	PORTD,LE
.ENDMACRO
;-------------------------------------------------------------------------------------------------------------------------

RESET: 
		cli 						; Disable interrupts	
		ldi		r16,high(0xDF)	; Main program start
		out 	SPH,r16 			; Set Stack Pointer to top of RAM
		ldi		r16,low(0xDF)
		out		SPL,r16



		cbi 	DDRB,DatIn \ sbi PORTB,DatIn	;INPUT

		sbi 	DDRD,Dat   \ sbi PORTD,Dat 
		sbi 	DDRD,CLK   \ sbi PORTD,CLK   
		sbi 	DDRD,LE    \ sbi PORTD,LE

		sbi 	DDRC,dR    \ sbi PORTC,dR 
		sbi 	DDRC,dG    \ sbi PORTC,dG 
		sbi 	DDRC,dB    \ sbi PORTC,dB 

		sbi 	DDRC,sR    \ cbi PORTC,sR 
		sbi 	DDRC,sG    \ sbi PORTC,sG 

		rcall	InitAnimColor

		rcall	SendFrame
		rcall	SendFrame
		rcall	SendFrame

		rcall	InitConfig	;send initialize config

		sei

		ldi		r16,0
		ldi		r17,0
		clr		r16

		clr		colR
		clr		colG
		clr		colB

		clr		cntC
		clr		timer
		clr		flash

;MainLoops:
;		clr		colR \ clr colG \ clr colB \ rcall	MakeColor \	rcall	SendFrame \ rcall	Waits
;		ser		colR \ ser colG \ ser colB \ rcall	MakeColor \	rcall	SendFrame \ rcall	Waits
;		
;		rjmp	MainLoops
;
MainLoop:
		inc		cntC
		cpi		cntC,0
		brne	_cntC
		inc		timer


.equ	ms10	= 1
		ldi		r16,ms10
;
		cp		timer,r16
		brne	no10ms
		clr		timer
// 100hz - refresh
		rcall	GetRGB
; miganie zielona diod status
		inc		flash

		mov		r16,flash
		cpi		r16,128
		brne	No_80
		sbi		Portc,sG
		
No_80:
		mov		r16,flash
		cpi		r16,255
		brne	No_160
		cbi		Portc,sG
		clr		flash
No_160:
;--------------------------------
		rcall	SendFrame
;--------------------------------
		rcall	SerialTestMBI
;--------------------------------
no10ms:
_cntC:
;-------
		cp		cntC,colR
		brlo	lowR		//skok gdy niszy
		cbi		Portc,dR
		rjmp	_lowR
lowR:
		sbi		PortC,dR
_lowR:
;-------

		cp		cntC,colG
		brlo	lowG		//skok gdy niszy
		cbi		Portc,dG
		rjmp	_lowG
lowG:
		sbi		PortC,dG
_lowG:
;-------

		cp		cntC,colB
		brlo	lowB		//skok gdy niszy
		cbi		Portc,dB
		rjmp	_lowB
lowB:
		sbi		PortC,dB
_lowB:
;-------
		rjmp		MainLoop
; ---------------------------------------------------------------------------------------------------------------------------------------------
Waits:
		ldi		r17,30
w7:
		ldi		r16,255

w8:
		nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop
		nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop \ nop
		dec		r16
		brne	w8
		dec		r17
		brne	w7
		ret
; ---------------------------------------------------------------------------------------------------------------------------------------------
;RAZ - InitAnimColor
; potem tylko GetRGB do nieskoczonoci
; ---------------------------------------------------------------------------------------------------------------------------------------------
InitAnimColor:
		ldi		ZH,High(tRGB*2)
		ldi		ZL,Low(tRGB*2)
		sts		pZH,ZH
		sts		pZL,ZL
		clr		r16;
		sts		Re,r16
		sts		Gr,r16
		sts		Bl,r16
		ldi		r16,20 \ sts xr20,r16

ac_loop:
// zrob kolory dla tla
		lds		ZH,pZH \ lds ZL,pZL
		lpm		r16,Z+ \ sts oRe,r16
		lpm		r16,Z+ \ sts oGr,r16
		lpm		r16,Z+ \ sts oBl,r16 \ adiw	Z,1
		sts		pZH,ZH \ sts pZL,ZL
		ldi		r16,255 \ sts xr21,r16
		ret
; ---------------------------------------------------------------------------------------------------------------------------------------------
GetRGB:

		lds		r16,Re \ lds r17,oRe \ add r16,r17 \ sts Re,r16 \ mov colR,r16
		lds		r16,Gr \ lds r17,oGr \ add r16,r17 \ sts Gr,r16 \ mov colG,r16
		lds		r16,Bl \ lds r17,oBl \ add r16,r17 \ sts Bl,r16 \ mov colB,r16
		
		lds		r16,xr21
		dec		r16
		brne	ExitsAC255

		rcall	ac_loop

		lds		r16,xr20
		dec		r16
		brne	ExitsXR20

		rjmp	InitAnimColor

ExitsAC255:
		sts		xr21,r16
		ret

ExitsXR20:
		sts		xr20,r16
		ret
; ---------------------------------------------------------------------------------------------------------------------------------------------

SerialTestMBI:
		ldi		r16,5	\ rcall	MBI8_Send
		ldi		r16,25	\ rcall	MBI8_Send
		ldi		r16,50	\ rcall	MBI8_Send
		ldi		r16,100	\ rcall	MBI8_Send
		ldi		r16,150	\ rcall	MBI8_Send
		ldi		r16,200 \ rcall	MBI8_Send

		ldi		r16,0	\ rcall	MBI8_Send \ cpi r17,5 \ brne ErrorMBI
		ldi		r16,0	\ rcall	MBI8_Send \ cpi r17,25 \ brne ErrorMBI
		ldi		r16,0	\ rcall	MBI8_Send \ cpi r17,50 \ brne ErrorMBI
		ldi		r16,0	\ rcall	MBI8_Send \ cpi r17,100 \ brne ErrorMBI
		ldi		r16,0	\ rcall	MBI8_Send \ cpi r17,150 \ brne ErrorMBI
		ldi		r16,0   \ rcall	MBI8_Send \ cpi r17,200 \ brne ErrorMBI

		; wysyamy 6 bajt
		; odieramy 6 bajt
		; porwnujemy 6 bajtw i zawiecamy bd gasimy czerwon diod
		cbi		Portc,sR	// - Zga diod R
		ret
ErrorMBI:
		sbi		Portc,sR
		ret
; ---------------------------------------------------------------------------------------------------------------------------------------------
//We: r16 - dana do wysania
//Wy: r17 - dana odebrana
MBI8_send:
		push	r18
		clr		r17
		ldi		r20,8
MBI8_Send_Loop:
		lsl		r16
		brcs	C8_1
		DAT_0
		rjmp C8_Out
C8_1:
		DAT_1
C8_Out:
		in		r18,PINB	;bit DataIn - INPUT
		ror		r18			; copy bit to C
		rol		r17			; bit C to R17

		CLK_1
		CLK_0

		dec		r20
		brne	MBI8_Send_Loop
		DAT_0
		pop		r18
		ret
; ---------------------------------------------------------------------------------------------------------------------------------------------
MakeColor:	; Tworz tablic kolorw w RAM dla 3 ukadw
		ldi		YH,High(MBI_RAM)
		ldi		YL,low(MBI_RAM)
// trzeba porobi wersj na 48 czyli 48 - 15 portw itd
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l15:	st		Y+,colR	\ st Y+,colG \ st Y+,colB \ dec r16 \ brne mc_l15	;15
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l14:	st		Y+,colG \ st Y+,colB \ st Y+,colR \ dec r16 \ brne mc_l14	;14
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l13:	st		Y+,colB \ st Y+,colR \ st Y+,colG \ dec r16 \ brne mc_l13	;13
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l12:	st		Y+,colR \ st Y+,colG \ st Y+,colB \ dec r16 \ brne mc_l12	;12
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l11:	st		Y+,colG \ st Y+,colB \ st Y+,colR \ dec r16 \ brne mc_l11	;11
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l10:	st		Y+,colB \ st Y+,colR \ st Y+,colG \ dec r16 \ brne mc_l10	;10
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l9:	st		Y+,colR \ st Y+,colG \ st Y+,colB \ dec r16 \ brne mc_l9 	;9
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l8:	st		Y+,colG \ st Y+,colB \ st Y+,colR \ dec r16 \ brne mc_l8 	;8
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l7:	st		Y+,colB \ st Y+,colR \ st Y+,colG \ dec r16 \ brne mc_l7 	;7
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l6:	st		Y+,colR \ st Y+,colG \ st Y+,colB \ dec r16 \ brne mc_l6 	;6
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l5:	st		Y+,colG \ st Y+,colB \ st Y+,colR \ dec r16 \ brne mc_l5 	;5
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l4:	st		Y+,colB \ st Y+,colR \ st Y+,colG \ dec r16 \ brne mc_l4 	;4
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l3:	st		Y+,colR \ st Y+,colG \ st Y+,colB \ dec r16 \ brne mc_l3 	;3
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l2:	st		Y+,colG \ st Y+,colB \ st Y+,colR \ dec r16 \ brne mc_l2 	;2
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l1:	st		Y+,colB \ st Y+,colR \ st Y+,colG \ dec r16 \ brne mc_l1 	;1
		ldi		r16,MBI_Count / 3		;48 ukadw	
mc_l0:	st		Y+,colR \ st Y+,colG \ st Y+,colB \ dec r16 \ brne mc_l0 	;0
		ret
; ---------------------------------------------------------------------------------------------------------------------------------------------
GetColor:	;pobiera kolor z MBI_RAM i zwraca warto w 16 bitach - parabolicznie
;		ld		r16,Y+
;		ldi		ZH,High(Colors*2) \ ldi ZL,Low(Colors*2)
;		clr		r17 \ lsl r16 \ rol r17						; kolor w 16bitach
;		add		ZL,r16
;		adc		ZH,r17
;		lpm		r16,Z+										; wartosc z tablicy
;		lpm		r17,Z+										; r17:r16 kolor

;alternatywnie - liniowo
		clr		r17
		ld		r16,Y+
		lsl 	r16 \ rol r17						; kolor w 16bitach		
		lsl 	r16 \ rol r17						; kolor w 16bitach
		lsl 	r16 \ rol r17						; kolor w 16bitach
		lsl 	r16 \ rol r17						; kolor w 16bitach
		ret
;-------------------------------------------------------------------------------------------------------------------------
SendFrame:
		push	r16
		push	r17
		push	r18
		push	r19
		push	r20
		push	r21
		push	r22

		rcall	MakeColor
		ldi		YH,High(MBI_RAM)
		ldi		YL,low(MBI_RAM)

		ldi		r18,15 ; ilosc portow
sf_loop:
;------------------------
		ldi		r19,MBI_Count-1 // iloc ukadw w szeregu
sfp_loop:
		rcall	GetColor
		rcall	MBI_Send
		dec		r19
		brne	sfp_loop
;------------------------
		rcall	GetColor
		rcall	MBI_Send_port
		dec		r18
		brne	sf_loop
;------------------------
		ldi		r19,MBI_Count-1 // iloc ukadw w szeregu
sfl_loop:
		rcall	GetColor
		rcall	MBI_Send
		dec		r19
		brne	sfl_loop
;------------------------
		rcall	GetColor
		rcall	MBI_Send_latch
;------------------------
		pop		r22
		pop		r21
		pop		r20
		pop		r19
		pop		r18
		pop		r17
		pop		r16
		ret
; ---------------------------------------------------------------------------------------------------------------------------------------------
;.equ MBI_Count   = 24 		; 16x8pix
;.equ MBI_RAM     = 0x0100	; size = MBI_Count * 32
; send ram to MBI
; organizacja w RAM to MBI_Count - 15 Port (Word) -> Data Latch
; organizacja w RAM to MBI_Count - 14 Port (Word) -> Data Latch
; ...
; organizacja w RAM to MBI_Count -  0 Port (Word) - >Global Latch
SendConfig:
		push	r16
		push	r17
		push	r18
		push	r19

		ldi		ZL,low(MBI_RAM)
		ldi		ZH,High(MBI_RAM)
;------------------------
		ldi		r19,MBI_Count-1 // iloc ukadw w szeregu
sfc_loop:
		ld		r16,Z+ \ ld r17,Z+			
		rcall	MBI_Send
		dec		r19
		brne	sfc_loop
;------------------------
		ld		r16,Z+ \ ld r17,Z+			
		rcall	MBI_Send_cfg
;------------------------
		pop		r19
		pop		r18
		pop		r17
		pop		r16
		ret
; ---------------------------------------------------------------------------------------------------------------------------------------------
InitConfig:	//send initialize config set all to 171 Gain
;                          FEDCBA9876543210 
		ldi		r17,high(0b0011100000000000 + (171 << 2))
		ldi		r16, low(0b0011100000000000 + (171 << 2))	;

		ldi		ZL,low(MBI_RAM)
		ldi		ZH,High(MBI_RAM)
		ldi		r18,MBI_Count
ic_Loop:
		st		Z+,r16
		st		Z+,r17
		dec		r18
		brne	ic_Loop
		rcall	SendConfig
		ret
; ---------------------------------------------------------------------------------------------------------------------------------------------
;send 16 bit from r17,r16
;r16,r17 - L,H - send
MBI_send:
		ldi		r20,16
MBI_Send_Loop:
		lsl		r16 \ rol r17
		brcs	C_1
		DAT_0
		rjmp C_Out
C_1:
		DAT_1
C_Out:
		CLK_0
		CLK_1
		CLK_0
		dec		r20
		brne	MBI_Send_Loop
		DAT_0
		ret
; ---------------------------------------------------------------------------------------------------------------------------------------------
;send 16 bit from r17,r16
;r16,r17 - L,H - send
MBI_send_port:
		ldi		r20,15
MBI_Send_port_Loop:
		lsl		r16 \ rol r17
		brcs	Cp_1
		DAT_0
		rjmp Cp_Out
Cp_1:
		DAT_1
Cp_Out:
		CLK_1
		CLK_0
		dec		r20
		brne	MBI_Send_port_loop

		lsl		r16 \ rol r17
		brcs	Cp2_1
		DAT_0	
		rjmp 	Cp2_Out
Cp2_1:
		DAT_1
Cp2_Out:
		LE_1
		CLK_1
		CLK_0
		LE_0
		ret
; ---------------------------------------------------------------------------------------------------------------------------------------------
;send 16 bit from r17,r16
;r16,r17 - L,H - send
MBI_send_latch:
		ldi		r20,13
MBI_Send_latch_Loop:
		lsl		r16 \ rol r17
		brcs	Cl_1
		DAT_0
		rjmp Cl_Out
Cl_1:
		DAT_1
Cl_Out:
		CLK_1
		CLK_0
		dec		r20
		brne	MBI_Send_latch_Loop

		lsl		r16 \ rol r17
		brcs	Cl2_1
		DAT_0	
		rjmp Cl2_Out
Cl2_1:
		DAT_1
Cl2_Out:
		LE_1
		CLK_1
		CLK_0

		lsl		r16 \ rol r17
		brcs	Cl2p_1
		DAT_0	
		rjmp Cl2p_Out
Cl2p_1:
		DAT_1
Cl2p_Out:
		CLK_1
		CLK_0

		lsl		r16 \ rol r17
		brcs	Cl3_1
		DAT_0	
		rjmp Cl3_Out
Cl3_1:
		DAT_1
Cl3_Out:
		CLK_1
		CLK_0
		LE_0
		ret
;-------------------------------------------------------------------------------------------
;send 16 bit from r17,r16
;r16,r17 - L,H - send
MBI_send_cfg:
		ldi		r20,5
;-------
MBI_Send_cfg_Loop:
		lsl		r16 \ rol r17
		brcs	Cf_1
		DAT_0	
		rjmp Cf_Out
Cf_1:
		DAT_1
Cf_Out:
		CLK_1
		CLK_0
		dec		r20
		brne	MBI_Send_cfg_Loop
;-------

		LE_1					;zakomunikowanie e leci konfig
		ldi		r20,10
MBI_Send_cfg2_Loop:
		lsl		r16 \ rol r17
		brcs	Cf2_1
		DAT_0	
		rjmp Cf2_Out
Cf2_1:
		DAT_1
Cf2_Out:
		CLK_1
		CLK_0
		dec		r20
		brne	MBI_Send_cfg2_Loop
;-------
		lsl		r16 \ rol r17
		brcs	Cf3_1
		DAT_0	
		rjmp Cf3_Out
Cf3_1:
		DAT_1
Cf3_Out:
		CLK_1
		CLK_0
		LE_0
		DAT_0
		ret
;-------------------------------------------------------------------------------------------
Colors: // 256 poziomw jasnoci
.dw      0,   2,   4,   6,   8,  10,  12,  14,  16,  18,  20,  22,  24,  26,  28,  30
.dw     32,  34,  36,  38,  40,  42,  44,  46,  48,  50,  52,  56,  60,  64,  70,  74
.dw     78,  84,  88,  96, 100, 106, 112, 118, 124, 130, 136, 142, 148, 156, 164, 170
.dw    178, 188, 192, 200, 208, 216, 224, 234, 242, 250, 258, 266, 276, 286, 294, 304
.dw	   314, 324, 334, 344, 354, 364, 374, 384, 396, 406, 418, 428, 440, 452, 464, 476
.dw	   488, 498, 510, 524, 536, 548, 560, 574, 588, 600, 612, 628, 640, 654, 668, 680
.dw	   694, 710, 724, 738, 752, 766, 782, 798, 812, 826, 842, 858, 874, 888, 904, 920
.dw    936, 952, 968, 984,1002,1018,1034,1052,1068,1086,1102,1120,1138,1152,1172,1190
.dw   1208,1226,1244,1262,1280,1298,1318,1336,1354,1374,1392,1412,1430,1450,1468,1488
.dw   1508,1528,1546,1566,1586,1606,1626,1646,1668,1688,1708,1728,1750,1770,1790,1812
.dw   1832,1854,1874,1896,1918,1938,1960,1982,2004,2026,2048,2068,2090,2112,2134,2158
.dw   2180,2202,2224,2246,2270,2292,2314,2338,2360,2382,2406,2428,2452,2476,2498,2522
.dw   2544,2568,2592,2616,2638,2662,2686,2710,2734,2758,2782,2806,2830,2854,2878,2902
.dw   2926,2950,2974,2998,3022,3046,3072,3096,3120,3144,3170,3194,3218,3244,3268,3292
.dw   3318,3342,3366,3392,3416,3442,3466,3492,3516,3542,3566,3592,3616,3642,3666,3692
.dw   3716,3742,3766,3792,3818,3842,3868,3892,3918,3944,3968,3994,4018,4044,4070,4094



tRGB:
.db		 1, 1, 1	,0
.db		-1,-1,-1	,0 
.db		 1, 1, 1	,0
.db		-1,-1,-1	,0 
.db		 1, 1, 1	,0
.db		-1,-1,-1	,0 
.db		 1, 1, 1	,0
.db		-1,-1,-1	,0 
.db		 1, 1, 1	,0
.db		-1,-1,-1	,0 
.db		 1, 1, 1	,0
.db		-1,-1,-1	,0 
.db		 1, 1, 1	,0
.db		-1,-1,-1	,0 
.db		 1, 1, 1	,0
.db		-1,-1,-1	,0 
.db		 1, 1, 1	,0
.db		-1,-1,-1	,0 
.db		 1, 1, 1	,0
.db		-1,-1,-1	,0 



.db		 1, 0, 0	,0
.db		-1, 0, 0	,0
.db		 0, 1, 0	,0
.db		 0,-1, 0	,0
.db		 0, 0, 1	,0
.db		 0, 0,-1	,0
.db		 1, 1, 0	,0
.db		-1,-1, 0	,0
.db		 0, 1, 1	,0
.db		 0,-1,-1	,0
.db		 1, 0, 1	,0
.db		-1, 0,-1	,0
.db		 1, 0, 0	,0
.db		-1, 1, 0	,0
.db		 1,-1, 1	,0
.db		-1, 1,-1	,0
.db		 0,-1, 1	,0
.db		 0, 0,-1	,0
.db		 1, 1, 1	,0
.db		-1,-1,-1	,0 

